<?php

declare(strict_types=1);

namespace Drupal\slots\Plugin\Field\FieldWidget;

use Drupal\conditions_field\Plugin\Field\FieldWidget\ConditionsGroupsWidget;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the 'slots' field widget.
 * 
 * @FieldWidget(
 *   id = "slots",
 *   label = @Translation("Slots (EXPERIMENTAL)"),
 *   field_types = {"slots"},
 * )
 */
class SlotsWidget extends ConditionsGroupsWidget {

  /**
   * {@inheritdoc}
   */
  public function form(FieldItemListInterface $items, array &$form, FormStateInterface $form_state, $get_delta = NULL) {
    $field_widget_complete_form = parent::form($items, $form, $form_state, $get_delta);

    // Show condition widget only if this checkbox is checked.
    $field_widget_complete_form['enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('This content shall be displayed in slots.'),
      '#default_value' => $form_state->get('number_of_condition_groups') > 0,
      '#weight' => -1,
    ];

    $parents = implode('][', $field_widget_complete_form['#parents']);
    $field_widget_complete_form['condition_groups']['#states'] = [
      'visible' => [':input[name="' . $parents . '[enable]"]' => ['checked' => TRUE]],
    ];

    return $field_widget_complete_form;
  }
}
